Struct futf::Codepoint
[−]
[src]
pub struct Codepoint<'a> {
pub bytes: &'a [u8],
pub rewind: usize,
pub meaning: Meaning,
}Represents a complete or partial UTF-8 codepoint.
Fields
bytes: &'a [u8]
The bytes that make up the partial or full codepoint.
For a Suffix this depends on idx. We don't scan forward
for additional continuation bytes after the reverse scan
failed to locate a multibyte sequence start.
rewind: usize
Start of the codepoint in the buffer, expressed as an offset
back from idx.
meaning: Meaning
Meaning of the partial or full codepoint.